@@ -16,3 +16,6 @@ pref("mail.biff.use_system_alert", true);
 
 // Use the system locale
 pref("intl.locale.requested", "");
+
+// Allow the use of existing GPG keyrings
+pref("mail.openpgp.allow_external_gnupg", true);
